/*
 * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
 */
package com.oracle.iot.flir.utils;

import java.io.*;
import java.nio.charset.StandardCharsets;

import org.json.JSONObject;

import com.oracle.iot.flir.utils.FLIRConnection.TemperatureUnits;
import com.oracle.iot.flir.utils.http.HttpSecureConnection;

public class Configuration {
    private String cameraUserName;
    private String cameraPassword;

    private TemperatureUnits cameraTemperatureUnits;

    private Double cameraLatitude;
    private Double cameraLongitude;
    
    private Double maxTemperature;

    private HttpSecureConnection iotConnection;

    public Configuration(File configFile) throws IOException {
        JSONObject config = readConfiguration(configFile);

        try {
            JSONObject cameraConfig = config.getJSONObject("camera");
            JSONObject cameraLocationConfig = cameraConfig.getJSONObject("location");
            JSONObject iotConfig = config.getJSONObject("iot");

            this.cameraUserName = cameraConfig.getString("userName");
            this.cameraPassword = cameraConfig.getString("password");

            this.cameraTemperatureUnits = TemperatureUnits.valueOf(cameraConfig.getString("temperatureUnits"));

            this.cameraLatitude = cameraLocationConfig.getDouble("latitude");
            this.cameraLongitude = cameraLocationConfig.getDouble("longitude");

            this.iotConnection = new HttpSecureConnection(iotConfig.getString("serverURL"),
                    iotConfig.getString("userName"), iotConfig.getString("password"));
            
            this.maxTemperature = config.getDouble("maxTemperature");
        } catch (Throwable t) {
            throw new IOException("Cannot proceed FLIR configuration", t);
        }
    }

    private JSONObject readConfiguration(File configFile) throws IOException {
        ByteArrayOutputStream out = new ByteArrayOutputStream();

        try (BufferedInputStream in = new BufferedInputStream(new FileInputStream(configFile))) {
            int b;

            while ((b = in.read()) != -1) {
                out.write(b);
            }
        }

        return new JSONObject(new String(out.toByteArray(), StandardCharsets.UTF_8));
    }

    public HttpSecureConnection getIOTConnection() {
        return iotConnection;
    }

    public String getCameraUserName() {
        return cameraUserName;
    }

    public String getCameraPassword() {
        return cameraPassword;
    }

    public TemperatureUnits getCameraTemperatureUnits() {
        return cameraTemperatureUnits;
    }

    public Double getCameraLatitude() {
        return cameraLatitude;
    }

    public Double getCameraLongitude() {
        return cameraLongitude;
    }

    public Double getMaxTemperature() {
        return maxTemperature;
    }
}
