/*
 * Copyright (c) 2019, Oracle and/or its affiliates.  All rights reserved.
 */
package com.oracle.iot.flir.utils.http;

import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.Map;

public class HttpResponse {
    private final int status;
    private final byte[] data;
    private final Map<String, List<String>> headers;

    public HttpResponse(int responseCode, byte[] data, Map<String, List<String>> headers) {
        this.status = responseCode;
        this.data = data;
        this.headers = headers;
    }

    public int getStatus() {
        return status;
    }

    public byte[] getData() {
        return data;
    }

    public Map<String, List<String>> getHeaders() {
        return headers;
    }

    public String getVerboseStatus(String method, String path) {
        final StringBuilder builder = new StringBuilder();
        if (method != null) {
            builder.append(method).append(' ');
        }
        
        if (path != null) {
            builder.append(path).append(": ");
        }
        
        builder.append("HTTP ").append(status);

        if (status < 200 || status >= 400) {
            if (data != null && data.length > 0) {
                builder.append(' ').append(new String(data, StandardCharsets.UTF_8));
            }
        }

        return builder.toString();
    }

    @Override
    public String toString() {
        return getVerboseStatus(null, null);
    }

}
