/*
 * Copyright (c) 2019, Oracle and/or its affiliates.  All rights reserved.
 */
package com.oracle.iot.flir.utils.http;

import java.net.MalformedURLException;
import java.net.URL;
import java.security.GeneralSecurityException;
import java.security.cert.CertificateException;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;

public class HttpSecureConnection extends AbstractHttpConnection {
    private SSLSocketFactory sslSocketFactory;

    public HttpSecureConnection(String hostUrl, String user, String password, Integer connectTimeout) throws GeneralSecurityException {
        super(hostUrl, user, password, connectTimeout);
    
        this.sslSocketFactory = createSSLSocketFactory();
    }
    
    public HttpSecureConnection(String hostUrl, String user, String password) throws GeneralSecurityException {
        this(hostUrl, user, password, null);
    }
    
    @Override
    protected HttpClient createHttpClient(URL url) throws MalformedURLException {
        return new HttpClient(sslSocketFactory, url, getConnectTimeout());
    }

    private SSLSocketFactory createSSLSocketFactory() throws GeneralSecurityException {
        final SSLContext sslContext = SSLContext.getInstance("TLS");

        TrustManager[] trustAllCerts = new TrustManager[] { new X509TrustManager() {
            public java.security.cert.X509Certificate[] getAcceptedIssuers() {
                return null;
            }

            @Override
            public void checkClientTrusted(java.security.cert.X509Certificate[] arg0, String arg1)
                    throws CertificateException {}

            @Override
            public void checkServerTrusted(java.security.cert.X509Certificate[] arg0, String arg1)
                    throws CertificateException {}

        } };

        sslContext.init(null, trustAllCerts, null);

        return sslContext.getSocketFactory();
    }
}
